function y = p_binomial(N,k,p)
% P_BINOMIAL calculate binomial probability
% N = number of trials
% k = number of event occurences
% p = probability of one event occuring at a trial
%
q = 1 - p;
y = nchoosek(N,k) * p^k * q^(N-k)
